
*This code loads the recoded ANES cumulative file and generates Figure 1 in Gerber/Huber
*(the relationship between PID and retrospective economic evaluations)
*The code at the top of the file shows how the ANES cumulative file is recoded. You will need
*that cumulative file to run the commented out code.
*
*Gregory Huber
*March 12, 2009


/*******************************************************************************
* Un-comment this big block of code to generate reduced dataset from raw ANES 
* cumulative file
********************************************************************************

set memory 100m
use anes_cdf.dta

gen year_of_study=VCF0004
label var year_of_study "Year of Study"
keep if year_of_study>=1980

/*
=============================================================================
VCF0301        7-pt Scale Party Identification
=============================================================================

QUESTION:
---------
Generally speaking, do you usually think of yourself as a Republican,
a Democrat, an Independent, or what?  (IF REPUBLICAN OR DEMOCRAT)
Would you call yourself a strong (REP/DEM) or a not very strong 
(REP/DEM)?  (IF INDEPENDENT, OTHER [1966 AND LATER: OR NO PREFERENCE]:)  
Do you think of yourself as closer to the Republican or Democratic party?

VALID_CODES:
------------
1.  Strong Democrat
2.  Weak Democrat
3.  Independent - Democrat        
4.  Independent - Independent
5.  Independent - Republican
6.  Weak Republican
7.  Strong Republican
9.  Apolitical (1966 only: and DK)

MISSING_CODES:
--------------
0.  DK; NA; other; refused to answer; no Pre IW
Inap. question not used

NOTES:
------
GENERAL NOTE:
APOLITICAL Code 9: In 1952-1966, an R who voluntarily specified complete
disinterest in politics ('I never vote,' 'I don't get involved in 
politics,' etc.) in response to party identification was coded as 
apolitical.  S/he was not then asked if s/he felt closer to either 
major party. In 1968-1980, 1984 an R who responded 'no preference'
to party identification and who responded with 'neither', DK or NA when 
asked if s/he felt closer to either major party was coded as apolitical 
if s/he otherwise also expressed a general disinterest in politics.
In 1982, 1986 and later, an R who expressed 'no preference' for party 
identification and who responded with 'neither,' DK or NA when asked if 
s/he felt closer to either major party was coded as apolitical IF s/he
also indicated little or no interest in politics in response to 
questions corresponding VCF0310, VCF0311/VCF0312, VCF0313, VCF0702).
INDEPENDENT - Code 4: In 1952-1966, an R was defined as independent if 
s/he responded 'independent' to party identification and then responded 
with 'neither,' DK or NA when asked if s/he felt closer to either major 
party. In 1968-1980 and 1984 an R was defined as independent (code 4 in 
VCF0301) if s/he responded 'independent' to party identification and 
then responded with 'neither,' DK or NA when asked if s/he felt closer 
to either major party.  An R was also defined as independent (code 4 in
VCF0301) if:  #1. s/he responded 'no preference' to party 
identification  AND #2. responded with 'neither,' DK or NA when asked 
if s/he felt closer to either major party AND #3. if s/he otherwise 
expressed some interest in politics.
INDEPENDENT/APOLITICAL - Codes 4/9: In 1982, 1986 and later,  an R who 
responded 'independent' to party identification and who then responded 
with 'neither,' DK or NA when asked if s/he felt closer to either major 
party was coded as independent (code 4 in VCF0301).  An R who expressed 
'no preference' for party identification and who responded with 
'neither,' DK or NA when asked if s/he felt closer to either major 
party was coded as independent (code 4 in VCF0301) IF s/he also 
indicated some interest in politics in response to the 4 questions 
listed above.
OTHER - Code 0: In all years, if an R responded to the party 
identification question with the mention of a minor party and then 
responded 'neither,' DK or NA when asked if s/he felt closer to either 
major party, then s/he has been coded "other."
LEANERS - Codes 3,5: 'Leaners' have included (all years): A. Rs who 
responded 'independent' to party identification and who responded with 
the mention of a major party when asked if s/he felt closer to either 
major party; B. Rs who responded to the party identification question 
with the mention of a minor party but who said they felt closer to one 
major party; C. Rs who responded to the party identification with 'no 
preference' but who said they felt closer to one major party.

WEIGHT:
-------
VCF0009/VCF0009a
*/

gen pid7=VCF0301-4
replace pid7=. if pid7>3 | pid7<-3
label var pid7 "PID 7 Cat (+3 Strong R -3 Strong D)"
drop if pid7==.

gen pid5=pid7
recode pid5 3=2 2=1 -2=-1 -3=-2
label var pid5 "Partisanship (5 Categories +2 Strong R to -2 Strong D)"

/*
=============================================================================
VCF0009a       Type 0 Weight - Post-Stratified Pre
=============================================================================

QUESTION:
---------
Type 0 weight - post-stratified

NOTES:
------
See NOTE ON WEIGHTS in the codebook appendix file.
All years same as VCF0009 except:  1994 and later.

TYPE:
-----
Numeric  Dec 4

SOURCE_VARS:
------------
1994:  940007a  
1996:  960005a  
1998:  980002
2000:  000002
2002:  020101
2004:  040101
*/

gen weight=VCF0009a

/*
=============================================================================
VCF0870        R Opinion: Better or Worse Economy in Past Year
=============================================================================

QUESTION:
---------
How about (1996-LATER: Now thinking about) the economy (1990,1994-
later: in the country as a whole)?
ALL YEARS EXC. 2000 VERSION 2:  
Would you say that over the past year the nation's economy has gotten 
better, stayed (all yrs. exc 1984: about) the same or gotten worse?
2000 VERSION 2: 
Would you say that over the past year the nation's economy has gotten 
worse, stayed about the same, or gotten better?

VALID_CODES:
------------
1.  Better
3.  Stayed same
5.  Worse

MISSING_CODES:
--------------
8.  DK
0.  NA
Inap. question not used

NOTES:
------
2000 NOTE: 
Respondents were randomly selected to be administered this question 
using either the standard format or and alternative version with the 
order of options read aloud reversed.

WEIGHT:
-------
VCF0009/VCF0009a

TYPE:
-----
Numeric  Dec 0

SOURCE_VARS:
------------
1980:  800149 
1982:  820327
1984:  840227 
1986:  860372
1988:  880243 
1990:  900422
1992:  923531 
1994:  940908 
1996:  960385 
1998:  980418
2000:  000488a,000488b 
2002:  023027
2004:  043097
*/

gen retecon=VCF0870
recode retecon 1=1 3=0 5=-1 8=. 0=.

keep year_of_study-retecon
compress

save recodedcdf.dta, replace

********************************************************************************
* Un-comment this big block of code to generate reduced dataset from raw ANES 
* cumulative file
*******************************************************************************/

use recodedcdf.dta

sort year_of_study pid5
collapse (mean) retecon [pweight=weight], by(year_of_study pid5)
label var retecon "Mean retrospective economy evaluation"
label define econlabel 1 "Better" 0 "Same" -1 "Worse"
label values retecon econlabel

egen meanretecon=mean(retecon), by(year)
gen demeanedretecon=retecon-meanretecon

gen dem_pres=0
replace dem_pres=1 if year_of_study==1980 | year_of_study==1994 | year_of_study==1996 | year_of_study==1998 | year_of_study==2000

label define demrep -2 "Strong D" -1 "Weak/Lean D" 0 "Independent" 1 "Weak/Lean R" 2 "Strong R"
label values pid5 demrep

twoway (line retecon pid5 if year_of_study==1980, scheme(s2mono) xtitle("") xlabel(, labsize(small) valuelabel) ylabel(-1(1)1, labsize(small) valuelabel nogrid)) (line retecon pid5 if year_of_study==1996) (line retecon pid5 if year_of_study==2000), legend(order(1 "1980 Carter" 2 "1996 Clinton" 3 "2000 Clinton") cols(2)) graphregion(color(white) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) icolor(white)) plotregion(fcolor(white)) title("A: Democratic President") name(DemGraph, replace)

twoway (line retecon pid5 if year_of_study==1984, scheme(s2mono) xtitle("") xlabel(, labsize(small) valuelabel) ytitle("") ylabel(none)) (line retecon pid5 if year_of_study==1988) (line retecon pid5 if year_of_study==1992) (line retecon pid5 if year_of_study==2004), legend(order(1 "1984 Reagan" 2 "1988 Reagan" 3 "1992 Bush I" 4 "2004 Bush II")) graphregion(color(white) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) icolor(white)) plotregion(fcolor(white)) title("B: Republican President") name(RepGraph, replace)

#delimit;

graph combine DemGraph RepGraph, scheme(s2mono) ycommon xcommon title(Figure 1: Partisanship and Retrospective Economic Evaluations, fcolor(white) lcolor(white))
note("Note: Source ANES Cumulative File, weighted analysis. Vertical axis is average response to: Would you say that over the past year the nation's economy has gotten better [1], stayed about the same [0] or gotten worse [-1]. Missing and Don't know responses excluded.", size(tiny))
xsize(6) ysize(3) graphregion(margin(zero) color(white) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white) icolor(white) lwidth(none) ilwidth(none)) plotregion(fcolor(white));

#delimit cr

graph export "Figure1_partyid_presparty_retecon.wmf", replace

graph set eps orientation landscape
graph set eps mag 180

graph export "Figure1_partyid_presparty_retecon.eps", as(eps) preview(off) fontface(Helvetica) mag(180) replace

