set memory 1g
set matsize 4000

pause on
set more off

use data\consolidated_salestaxandelectiondata.dta, replace

***
*Recode variables
***

*1 in election year, 0 otherwise
gen preselecyear=0
replace preselecyear=1 if (year/4)==int(year/4)

*1 when dem wins, -1 when rep wins, 0 otherwise
gen presdemwin=0
replace presdemwin=-1 if preselecyear==1
replace presdemwin=1 if year==1992 | year==1996

*interact preswinner and partisanship measures
gen dpct2p_8088_demwin=dempres2pavg_8088*presdemwin
gen dpct2p_8000_demwin=dempres2pavg_8000*presdemwin
gen dpct2p_9204_demwin=dempres2pavg_9204*presdemwin

gen dpct2p_80_demwin=dempres2p_80*presdemwin
gen dpct2p_00_demwin=dempres2p_00*presdemwin

label var dpct2p_8088_demwin "Avg. Dem. prop. 2-party Pres. vote 1980-1988 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_8000_demwin "Avg. Dem. prop. 2-party Pres. vote 1980-2000 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_9204_demwin "Avg. Dem. prop. 2-party Pres. vote 1992-2004 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_80_demwin "Dem. prop. 2-party Pres. vote 1980 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_00_demwin "Dem. prop. 2-party Pres. vote 2000 x Pres. win (1=Dem., -1=Rep.)"

*year dummies
quietly tab year, gen(yind_)
drop yind_29

***
*Other Interactions with Dem. Win
***

gen logpci_demwin=logpci*presdemwin
gen pci_demwin=pci*presdemwin
gen dw_propblack2000=propblack2000*presdemwin
gen dw_loghhinc1997=loghhinc1997*presdemwin
gen dw_proppov1997=proppov1997*presdemwin
gen dw_propss1999=propss1999*presdemwin
gen dw_educ00=prop25andovercollegeplus*presdemwin
gen dw_logfedfundspercap=logfedfundspercap*presdemwin
gen dw_logtranspercap1998=logtranspercap1998*presdemwin
gen dw_propgov=propgov*presdemwin
gen dwa_logmfgvalueaddpercap1997=logmfgvalueaddpercap1997*presdemwin
gen dw_logfarmsalespercap1997=logfarmsalespercap1997*presdemwin
gen dw_logbankpercap1999=logbankpercap1999*presdemwin
gen dw_metrocty=metrocty*presdemwin
gen dw_mining=mining*presdemwin
gen dw_mfg=mfg*presdemwin
gen dw_reccty=reccty*presdemwin
gen dw_retirecty=retirecty*presdemwin
gen dw_mempercap=mempercap*presdemwin

label var dw_educ00 "Prop. Pop. Age 25+ w/ BA or more 2000 x Pres. Win"
label var dw_propblack2000 "Prop. Pop. Black 2000 x Pres. Win"
label var dw_loghhinc1997 "Log Median Household Income 1997 ($1,000s) x Pres. Win"
label var dw_proppov1997 "Prop. Pop. in Poverty 1997 x Pres. Win"
label var dw_logfedfundspercap "Log Federal Funds and Grants Per Capita 1999 ($1,000s) x Pres. Win"
label var dw_logtranspercap1998 "Log Government Transfers Per Capita 1998 ($1,000s) x Pres. Win"
label var dwa_logmfgvalueaddpercap1997 "Log Manufacturing Value Added Per Capita 1997 ($1,000s) x Pres. Win"
label var dw_logfarmsalespercap1997 "Log Value of Farm Products Sold Per Capita 1997 ($1,000s) x Pres. Win"
label var dw_logbankpercap1999 "Log Banking Deposits Per Capita 1999 ($1,000s) x Pres. Win"
label var dw_propss1999 "Prop. Pop. Receiving Social Security 1999 x Pres. Win"
label var dw_propgov "Prop. Pop. Working for Government (Civilian and Military) 1998 x Pres. Win"
label var dw_metrocty "Metropolitan county x Pres. Win"
label var dw_mining "Mining-dependent county x Pres. Win"
label var dw_mfg "Manufacturing-dependent county x Pres. Win"
label var dw_reccty "Recreation-destination county x Pres. Win"
label var retirecty "Retirement-destination county"
label var dw_retirecty "Retirement-destination county x Pres. Win"
label var dw_mempercap "Church members per capita 1990 x Pres. Win"

log using "logs\SalesTaxAnalysis.log", text replace

***
*Label variables
***

label var pci "Per Capita Income 2000 ($10,000s)"
label var pci_demwin "Per Capita Income 2000 ($10,000s) x Pres. win (1=Dem., -1=Rep.)"

label var logpci "Log Per Capita Income 2000 ($1,000s)"
label var logpci_demwin "Log Per Capita Income 2000 ($1,000s) x Pres. win (1=Dem., -1=Rep.)"

label var fips_st "county/area"

*****************************************************************************************
*Change in difference estimates relative to prior 3 years with county/area fixed effects*
*****************************************************************************************

*Note that these year dummies are only defined for pres-elec years, so sample is automatically restricted to those years
drop yind_*
tab year if preselec==1, gen(yind_)
drop yind_7
rename yind_1 yind_1980
rename yind_2 yind_1984
rename yind_3 yind_1988
rename yind_4 yind_1992
rename yind_5 yind_1996
rename yind_6 yind_2000

label var yind_1980 "Year=1980"
label var yind_1984 "Year=1984"
label var yind_1988 "Year=1988"
label var yind_1992 "Year=1992"
label var yind_1996 "Year=1996"
label var yind_2000 "Year=2000"

*****
*Variable Codings that follow are for placebo-controlled model
*****

*For the Placebo-controlled model, let's look at change in sales in the year before the election as a function of (forward-looking) election outcome
tab year if ((year+1)/4)==int((year+1)/4), gen(ypind_)
drop ypind_7
rename ypind_1 ypind_1979
rename ypind_2 ypind_1983
rename ypind_3 ypind_1987
rename ypind_4 ypind_1991
rename ypind_5 ypind_1995
rename ypind_6 ypind_1999

label var ypind_1979 "Year=1979"
label var ypind_1983 "Year=1983"
label var ypind_1987 "Year=1987"
label var ypind_1991 "Year=1991"
label var ypind_1995 "Year=1995"
label var ypind_1999 "Year=1999"

*1 in year prior to election year, 0 otherwise
gen preselecnextyear=0
replace preselecnextyear=1 if ((year+1)/4)==int((year+1)/4)

*1 when dem will win, -1 when rep will win, 0 otherwise
gen presdemwinnext=0
replace presdemwinnext=-1 if preselecnextyear==1
replace presdemwinnext=1 if year==1991 | year==1995

*interact presdemwinnext and partisanship
gen pct2p_nextdemwin=dempres2pavg_8088*presdemwinnext
gen pct2p9204_nextdemwin=dempres2pavg_9204*presdemwinnext

*interact presdemwinnext and income
gen logpci_nextdemwin=logpci*presdemwinnext
gen pci_nextdemwin=pci*presdemwinnext

label var logpci_nextdemwin "Log Per Capita Income 2000 ($1,000s) x Pres. win (1=Dem., -1=Rep.) in following year"
label var pct2p_nextdemwin "Avg. Dem. prop. 2-party Pres. vote 1980-1988 x Pres. win (1=Dem., -1=Rep.) in following year"
label var pct2p9204_nextdemwin "Avg. Dem. prop. 2-party Pres. vote 1992-2004 x Pres. win (1=Dem., -1=Rep.) in following year"

/****************************************************************************************
*We want to run these models on places that have at least one dem win and one rep. win.
*The easiest way to do that is to run this code to construct the following data set.
*Note here that we use the 2000 vote, because that allows us to keep Maine and Vermont,
*where we only have sub-county level measures of vote outcomes for 2000.
****************************************************************************************/
   
preserve

quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dpct2p_00_demwin if year>=1990, fe i(fipsindx)
gen used=e(sample)
gen dcase=1 if used==1 & (year==1992 | year==1996)
gen rcase=1 if used==1 & (year==2000 | year==2004)
sort fipsindx
replace dcase=0 if dcase==.
replace rcase=0 if rcase==.
sort fipsindx
collapse (max) dcase rcase, by(fipsindx)
gen useme=1 if dcase==1 & rcase==1
replace useme=0 if useme==.
sort fipsindx
drop dcase rcase
rename useme CaseHasOneDandRwin
sort fipsindx
save data\cases_to_use.dta, replace
clear

restore

*Merge back in list of cases with at least one victory by each side

sort fipsindx
joinby fipsindx using data\cases_to_use.dta, unmatched(master)

/****************************************************************************************
****************************************************************************************/

/****************************************************************************************
*
* Table 2: summary stats.
* Note sample restriction is same as column (1) of Table 3
*
****************************************************************************************/

quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dempres2pavg_9204 if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)

gen makesumstatscases=e(sample)

#delimit ;

summ logchg1qfrom3q dempres2pavg_9204 logpci propblack2000 proppov1997 propss1999 propgov logfarmsalespercap1997 metrocty
loghhinc1997 prop25andovercollegeplus logfedfundspercap logtranspercap1998 logbankpercap1999 mining mfg reccty retirecty mempercap
if makesumstatscases==1, sep(0);

outsum logchg1qfrom3q dempres2pavg_9204 logpci propblack2000 proppov1997 propss1999 propgov logfarmsalespercap1997 metrocty
loghhinc1997 prop25andovercollegeplus logfedfundspercap logtranspercap1998 logbankpercap1999 mining mfg reccty retirecty mempercap
if makesumstatscases==1 using logs\Table2.out, replace;

#delimit cr

drop makesumstatscases

***
*Table 3, with 92-04 Dpres.
*Includes all states where we have data for at least one Democratic win and excludes elections prior to 1992 (because of partisan imbalance in missing data)
***

*This regression is used to set sample for the dummy variables
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dpct2p_9204_demwin if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)

egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

*County and State-Year Fixed Effects
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and State-Year Fixed Effects") replace

*County Year Fixed Effects
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and Year Fixed Effects") append

*1980-00 partisanship, County and State-Year Fixed Effects
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_8000_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_8000_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (1), Partisanship 1980-2000") append

*1980-00 partisanship, County Year Fixed Effects
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_8000_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_8000_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (2), Partisanship 1980-2000") append

drop fid_* syd_* syg

*PLACEBO REGRESSIONS
*NOTE: Running these regressions on the entire sample produces an abnormally low R2.
*It turns out that that source of that results is Iowa in 1996, due to the effect of flooding in early 1993 (which enters as the lagged value)
*For this reason, we report results excluding Iowa 1996

*1q to 3q within year effects

*Run this regression to set sample for the dummy variables
quietly xtreg logchg3qfrom1q avg_3yr_log1qto3q yind_1992-yind_2000 dpct2p_9204_demwin if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)

egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg3qfrom1q avg_3yr_log1qto3q dpct2p_9204_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1 & (state~="ia" | year~=1996), cluster(fipsindx)
outreg avg_3yr_log1qto3q dpct2p_9204_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) append ctitle("Model (1), 1q to 3q before election") 

regress logchg3qfrom1q avg_3yr_log1qto3q dpct2p_9204_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1 & (state~="ia" | year~=1996), cluster(fipsindx)
outreg avg_3yr_log1qto3q dpct2p_9204_demwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) append ctitle("Model (2), 1q to 3q before election") 

drop fid_* syd_* syg

*Run this regression to set sample for the dummy variables
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q pct2p9204_nextdemwin ypind_1991-ypind_1999  if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)
egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg1qfrom3q avg_3yr_log3qto1q pct2p9204_nextdemwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1 & (state~="ia" | year~=1995), cluster(fipsindx)
outreg avg_3yr_log3qto1q pct2p9204_nextdemwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) append ctitle("Model (1), 3q to 1q year before election") 

regress logchg1qfrom3q avg_3yr_log3qto1q pct2p9204_nextdemwin ypind_1991-ypind_1999 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1 & (state~="ia" | year~=1995), cluster(fipsindx)
outreg avg_3yr_log3qto1q pct2p9204_nextdemwin using logs\Table3.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) append ctitle("Model (2), 3q to 1q year before election") 

drop fid_* syd_* syg

***
*Table 4, Alternative Models and Persistence
***

*This regression is used to set sample for the dummy variables
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 logpci_demwin dpct2p_9204_demwin dw_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)
gen useme=e(sample)

egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

*BASE, this sample
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin syd_* fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin  using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and State-Year Fixed Effects, this sample") replace

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin yind_1992-yind_2000 fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin  using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and Year Fixed Effects, this sample") append

*With a few covariates
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_propblack2000 dw_proppov1997 dw_propss1999 dw_propgov dw_logfarmsalespercap1997 dw_metrocty syd_* fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_propblack2000 dw_proppov1997 dw_propss1999 dw_propgov dw_logfarmsalespercap1997 dw_metrocty using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (1), Mechanism I") append

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_propblack2000 dw_proppov1997 dw_propss1999 dw_propgov dw_logfarmsalespercap1997 dw_metrocty yind_1992-yind_2000  fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_propblack2000 dw_proppov1997 dw_propss1999 dw_propgov dw_logfarmsalespercap1997 dw_metrocty using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (2), Mechanism I") append

*Alt. mechanisms
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_* syd_* fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_* using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (1), Mechanism II") append

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_* yind_1992-yind_2000  fid_* if useme==1 & year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin logpci_demwin dw_* using logs\Table4.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Model (2), Mechanism II") append

drop fid_* syd_* syg useme

***
*Table 6: Persistence
***

*enduring effects, 3q to 3q model

*This regression is used to set sample for the dummy variables
quietly xtreg logchg3qfrom3q avg_3yr_log3qto3q dpct2p_9204_demwin yind_1992-yind_2000 if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)

egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg3qfrom3q avg_3yr_log3qto3q dpct2p_9204_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto3q dpct2p_9204_demwin using logs\Table6.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and State-Year Fixed Effects") replace

regress logchg3qfrom3q avg_3yr_log3qto3q dpct2p_9204_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto3q dpct2p_9204_demwin using logs\Table6.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("County and Year Fixed Effects") append

*Alt. mechanisms
regress logchg3qfrom3q avg_3yr_log3qto3q dpct2p_9204_demwin logpci_demwin dw_* syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto3q dpct2p_9204_demwin logpci_demwin dw_* using logs\Table6.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Persistence, Mechanism, Model (1)") append

regress logchg3qfrom3q avg_3yr_log3qto3q dpct2p_9204_demwin logpci_demwin dw_* yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto3q dpct2p_9204_demwin logpci_demwin dw_* using logs\Table6.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Persistence, Mechanism, Model (2)") append

drop fid_* syd_* syg 

***
*Table 7: Sensitivity analyses, in paper.
***

*Sensitivity to clustering/fixed effects
quietly regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin dempres2pavg_9204 yind_1992-yind_2000 if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

*State-Year Effects, cluster State-Year 
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin dempres2pavg_9204 syd_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(syg)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin dempres2pavg_9204 using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Only State-Year Fixed Effects, cluster state-year") replace

*Year Effects, cluster State-Year
regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_9204_demwin dempres2pavg_9204 yind_1992-yind_2000 if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(syg)
outreg avg_3yr_log3qto1q dpct2p_9204_demwin dempres2pavg_9204 using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Only Year Fixed Effects, cluster state-year") append

*No lag, cluster State-year
regress logchg1qfrom3q dpct2p_9204_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(syg)
outreg dpct2p_9204_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("No lagged D.V., County and Year Fixed Effects, Cluster State-Year") append

drop fid_* syd_* syg 

*Alt measures of partisanship

*1980 
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dpct2p_80_demwin if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)
egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_80_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_80_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Partisanship, 1980") append

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_80_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_80_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Partisanship, 1980") append

drop fid_* syd_* syg 

*2000 with reservations all elections 1992-2004 (gives us ME) 
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1984-yind_2000 dpct2p_00_demwin, fe i(fipsindx) cluster(fipsindx)
egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_00_demwin syd_* fid_* if year>=1990, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_00_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Partisanship, 2000, all obs 1992-2004 with res.") append

regress logchg1qfrom3q avg_3yr_log3qto1q dpct2p_00_demwin yind_1984-yind_2000 fid_* if year>=1990, cluster(fipsindx)
outreg avg_3yr_log3qto1q dpct2p_00_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Partisanship, 2000, all obs 1992-2004 with res.") append

drop fid_* syd_* syg 

*democratic versus republican counties
gen dem_dpct2p9204_demwin=0 if dempres2pavg_9204~=.
gen rep_dpct2p9204_demwin=0 if dempres2pavg_9204~=.
replace dem_dpct2p9204_demwin=dpct2p_9204_demwin if dempres2pavg_9204>=.40
replace rep_dpct2p9204_demwin=dpct2p_9204_demwin if dempres2pavg_9204<.40

label var dem_dpct2p9204_demwin "Avg. Dem. prop. 2-party vote 1992-2004 x Pres. win x Dem. prop >= .40"
label var rep_dpct2p9204_demwin "Avg. Dem. prop. 2-party vote 1992-2004 x Pres. win x Dem. prop < .40"

quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dem_dpct2p9204_demwin rep_dpct2p9204_demwin if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)
egen syg=group(state year) if e(sample)
quietly tab syg, gen(syd_)
quietly tab fipsindx if e(sample), gen(fid_)
drop fid_1

regress logchg1qfrom3q avg_3yr_log3qto1q dem_dpct2p9204_demwin rep_dpct2p9204_demwin syd_* fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dem_dpct2p9204_demwin rep_dpct2p9204_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Seperate Effects for Dem. and Rep. Counties") append

regress logchg1qfrom3q avg_3yr_log3qto1q dem_dpct2p9204_demwin rep_dpct2p9204_demwin yind_1992-yind_2000 fid_* if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, cluster(fipsindx)
outreg avg_3yr_log3qto1q dem_dpct2p9204_demwin rep_dpct2p9204_demwin using logs\Table7.out, bracket coefastr 3aster se bfmt(fc) bdec(3) tdec(5) ctitle("Seperate Effects for Dem. and Rep. Counties") append

drop fid_* syd_* syg 



