set memory 500m
set matsize 1000

pause on
set more off

use data\consolidated_salestaxandelectiondata.dta

***
*Recode variables
***

*1 in election year, 0 otherwise
gen preselecyear=0
replace preselecyear=1 if (year/4)==int(year/4)

*1 when dem wins, -1 when rep wins, 0 otherwise
gen presdemwin=0
replace presdemwin=-1 if preselecyear==1
replace presdemwin=1 if year==1992 | year==1996

*****************************************************************************************
*Change in difference estimates relative to prior 3 years with county/area fixed effects*
*****************************************************************************************

drop if year/4~=int(year/4)
drop if dempres2pavg_9204==.
drop if year<1992

gen logchg1qfrom3qdemwin=logchg1qfrom3q*presdemwin

sort fipsindx
collapse (sum) logchg1qfrom3qdemwin (count) ct=logchg1qfrom3qdemwin (mean) dempres2pavg_9204, by(fipsindx)
replace logchg1qfrom3qdemwin=logchg1qfrom3qdemwin/4

*Get rid of counties that don't have four observations (1992, 1996, 2000, 2004)
drop if ct~=4

replace ct=1

gen dempct=int(((dempres2pavg_9204*100)+2.5)/5)*5
sort dempct
collapse (mean) logchg1qfrom3qdemwin (sum) ct, by(dempct)

label var ct "Number of Observations"
label var logchg1qfrom3qdemwin "Average Change D.V., Dem. Pres. Wins - Rep. Pres Wins"
label var dempct "Democratic Percentage 2-party vote 1992-2004"
rename logchg1qfrom3qdemwin avglogchg1qfrom3qdemwin

regress avglogchg1qfrom3qdemwin dempct [aweight=ct]
predict dvhat
summ ct if e(sample)

label var dvhat "Predicted values, area by area linear regression [1505 Counties]"

regress avglogchg1qfrom3qdemwin dempct if ct>=50 [aweight=ct]
predict dvhat2 if e(sample)
summ ct if e(sample)

label var dvhat2 "Predicted values for levels of vote share with at least 50 obs. [1427 Counties]"

twoway  (scatter avglogchg1qfrom3qdemwin dempct, msymbol(square) mcolor(black)), scheme(s2mono)

#delimit ;

twoway  (scatter avglogchg1qfrom3qdemwin dempct, msymbol(square) mcolor(black))
(line dvhat dempct, lcolor(black) lpattern(solid)) 
(line dvhat2 dempct, lcolor(black) lpattern(dot)) 
(line ct dempct, yaxis(2) lcolor(gs10) lpattern(dash) lwidth(thin))
,scheme(s2mono) graphregion(fcolor(white) lcolor(none))
title("Figure 2: Average change in consumption 1992 and 1996 - Average change in consumption 2000 and 2004",size(vsmall))
subtitle("(Democratic minus Republican victories)",size(vsmall)) 
note("Change in consumption is Log[Next year's 1Q sales/Current year's 3Q sales].",size(vsmall)) 
caption("Includes all areas with observations for 1992, 1996, 2000, and 2004.", size(vsmall)) 
legend(on size(vsmall) colfirst notextfirst nostack cols(1))
xlabel(15(5)80) xlabel(, labsize(small) ) 
xtitle(, size(small) ) 
ylabel(, labsize(small) axis(2))
ytitle(, size(small) axis(2));

#delimit cr 

graph export "logs\Figure2_19922004Partisanship.eps", as(eps) preview(off) fontface(Helvetica) mag(200) orientation(landscape) replace
graph export "logs\Figure2_19922004Partisanship.wmf", as(wmf) replace

